# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: identity/enums.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14identity/enums.proto\x12\x11\x63loudidl.identity*2\n\rResponseTypes\x12\x08\n\x04\x43ODE\x10\x00\x12\t\n\x05TOKEN\x10\x01\x12\x0c\n\x08ID_TOKEN\x10\x02*&\n\x0f\x41pplicationType\x12\x07\n\x03WEB\x10\x00\x12\n\n\x06NATIVE\x10\x01*|\n\nGrantTypes\x12\x16\n\x12\x41UTHORIZATION_CODE\x10\x00\x12\x0c\n\x08IMPLICIT\x10\x01\x12\x0c\n\x08PASSWORD\x10\x02\x12\x16\n\x12\x43LIENT_CREDENTIALS\x10\x03\x12\x11\n\rREFRESH_TOKEN\x10\x04\x12\x0f\n\x0b\x44\x45VICE_CODE\x10\x05*T\n\x17TokenEndpointAuthMethod\x12\x08\n\x04NONE\x10\x00\x12\x16\n\x12\x43LIENT_SECRET_POST\x10\x01\x12\x17\n\x13\x43LIENT_SECRET_BASIC\x10\x02*a\n\rConsentMethod\x12\x17\n\x13\x43ONSENT_METHOD_NONE\x10\x00\x12\x1a\n\x16\x43ONSENT_METHOD_TRUSTED\x10\x01\x12\x1b\n\x17\x43ONSENT_METHOD_REQUIRED\x10\x02\x42\xb7\x01\n\x15\x63om.cloudidl.identityB\nEnumsProtoH\x02P\x01Z+github.com/unionai/cloud/gen/pb-go/identity\xa2\x02\x03\x43IX\xaa\x02\x11\x43loudidl.Identity\xca\x02\x11\x43loudidl\\Identity\xe2\x02\x1d\x43loudidl\\Identity\\GPBMetadata\xea\x02\x12\x43loudidl::Identityb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'identity.enums_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025com.cloudidl.identityB\nEnumsProtoH\002P\001Z+github.com/unionai/cloud/gen/pb-go/identity\242\002\003CIX\252\002\021Cloudidl.Identity\312\002\021Cloudidl\\Identity\342\002\035Cloudidl\\Identity\\GPBMetadata\352\002\022Cloudidl::Identity'
  _globals['_RESPONSETYPES']._serialized_start=43
  _globals['_RESPONSETYPES']._serialized_end=93
  _globals['_APPLICATIONTYPE']._serialized_start=95
  _globals['_APPLICATIONTYPE']._serialized_end=133
  _globals['_GRANTTYPES']._serialized_start=135
  _globals['_GRANTTYPES']._serialized_end=259
  _globals['_TOKENENDPOINTAUTHMETHOD']._serialized_start=261
  _globals['_TOKENENDPOINTAUTHMETHOD']._serialized_end=345
  _globals['_CONSENTMETHOD']._serialized_start=347
  _globals['_CONSENTMETHOD']._serialized_end=444
# @@protoc_insertion_point(module_scope)
